=========
ChangeLog
=========


v0.3.0
======

* Added Python 3 support
  (thanks to github.com/farvour -- issue #3)
* Implemented workaround for kombu (python3 + pickle + bzip2) issue


v0.2.5
======

* Added ultra-basic unit test
* Fixed serializer to work with kombu 3.0.8
  (thanks to github.com/mazvv -- issue #2)


v0.2.4
======

* First tagged release
